Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(776)

Unified Diff: content/renderer/p2p/ipc_socket_factory.h

Issue 429113002: Webrtc deps roll. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Use webrtc version 6825 and rebase and switch back to original workspace. Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/renderer/p2p/ipc_network_manager.cc ('k') | content/renderer/p2p/ipc_socket_factory.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/p2p/ipc_socket_factory.h
diff --git a/content/renderer/p2p/ipc_socket_factory.h b/content/renderer/p2p/ipc_socket_factory.h
index cba98b3c0d060c452a178ade4da5434a213bfef8..53e1edc2feabc7868fe6d196d40d8bfb31ae2d81 100644
--- a/content/renderer/p2p/ipc_socket_factory.h
+++ b/content/renderer/p2p/ipc_socket_factory.h
@@ -14,33 +14,33 @@ namespace content {
class P2PSocketDispatcher;
-// IpcPacketSocketFactory implements talk_base::PacketSocketFactory
+// IpcPacketSocketFactory implements rtc::PacketSocketFactory
// interface for libjingle using IPC-based P2P sockets. The class must
// be used on a thread that is a libjingle thread (implements
// talk_base::Thread) and also has associated base::MessageLoop. Each
// socket created by the factory must be used on the thread it was
// created on.
-class IpcPacketSocketFactory : public talk_base::PacketSocketFactory {
+class IpcPacketSocketFactory : public rtc::PacketSocketFactory {
public:
CONTENT_EXPORT explicit IpcPacketSocketFactory(
P2PSocketDispatcher* socket_dispatcher);
virtual ~IpcPacketSocketFactory();
- virtual talk_base::AsyncPacketSocket* CreateUdpSocket(
- const talk_base::SocketAddress& local_address,
+ virtual rtc::AsyncPacketSocket* CreateUdpSocket(
+ const rtc::SocketAddress& local_address,
int min_port, int max_port) OVERRIDE;
- virtual talk_base::AsyncPacketSocket* CreateServerTcpSocket(
- const talk_base::SocketAddress& local_address,
+ virtual rtc::AsyncPacketSocket* CreateServerTcpSocket(
+ const rtc::SocketAddress& local_address,
int min_port,
int max_port,
int opts) OVERRIDE;
- virtual talk_base::AsyncPacketSocket* CreateClientTcpSocket(
- const talk_base::SocketAddress& local_address,
- const talk_base::SocketAddress& remote_address,
- const talk_base::ProxyInfo& proxy_info,
+ virtual rtc::AsyncPacketSocket* CreateClientTcpSocket(
+ const rtc::SocketAddress& local_address,
+ const rtc::SocketAddress& remote_address,
+ const rtc::ProxyInfo& proxy_info,
const std::string& user_agent,
int opts) OVERRIDE;
- virtual talk_base::AsyncResolverInterface* CreateAsyncResolver() OVERRIDE;
+ virtual rtc::AsyncResolverInterface* CreateAsyncResolver() OVERRIDE;
private:
P2PSocketDispatcher* socket_dispatcher_;
« no previous file with comments | « content/renderer/p2p/ipc_network_manager.cc ('k') | content/renderer/p2p/ipc_socket_factory.cc » ('j') | no next file with comments »
@@ -14,33 +14,33 @@ namespace content {
// interface for libjingle using IPC-based P2P sockets. The class must
// be used on a thread that is a libjingle thread (implements
-// talk_base::Thread) and also has associated base::MessageLoop. Each
+// rtc::Thread) and also has associated base::MessageLoop. Each
// socket created by the factory must be used on the thread it was
// created on.

Powered by Google App Engine
This is Rietveld 408576698